#ifndef DICTBROWSER_H
#define DICTBROWSER_H

#include <QTextBrowser>

class DictPage;

class DictBrowser : public QTextBrowser
{
	Q_OBJECT

public:
	DictBrowser(QWidget *parent = 0);
	~DictBrowser();
	QStringList backwardList(int len = 10) const
		{ return historyList(backwardHistory, len); }
	QStringList forwardList(int len = 10) const
		{ return historyList(forwardHistory, len); }
	int historySize() const { return histSize; }
	void setHistorySize(int size) { histSize = size; }
	QFont textFont() const { return document()->defaultFont(); }
	void setTextFont(const QFont &font);
	void setStyleSheet(const QString &style);
	DictPage *dictPage() const { return page; }
	QString pageText() const;

public Q_SLOTS:
	void backward() { moveTo(-1); }
	void forward() { moveTo(1); }
	void moveTo(int steps);
	void setPage(const QString &query, const QString &text);
	void appendPage(const QString &query, const QString &text);
	void plainText(bool toggle);
	void clearHistory();
	void busyCursor(bool busy);
	void pointCursor(const QString &text);
	void preview(QPrinter *printer) { print(printer); }

private Q_SLOTS:
	void setPage(bool append);
	void focusOutEvent(QFocusEvent *event);
	void selection();

Q_SIGNALS:
	void historyChanged(const QString &);

private:
	friend class DictSearch;
	struct HistoryEntry {
		QString title, page;
		int hpos, vpos, type;
	};

	QList<HistoryEntry> backwardHistory, forwardHistory;
	HistoryEntry entry;
	QStringList historyList(const QList<HistoryEntry> &history, int len) const;
	int histSize;
	void savePosition();
	void restorePosition();

	bool plaintext;
	void displayPage(const QString &text);
	void reload();

	QCursor cursor;
	void clearSelection();

	DictPage *page;
};

#endif
