#include "dictgroup.h"

#include <QListWidget>
#include <QInputDialog>


DictEditConf::DictEditConf(QWidget *parent)
	: KDialog(parent)
{
	setupUi(mainWidget());
	setCaption(i18n("Edit Databases"));

	connect(groupbox, SIGNAL(activated(int)), SLOT(select(int)));

	addButton->setIcon(KIcon("list-add"));
	removeButton->setIcon(KIcon("list-remove"));
	connect(addButton, SIGNAL(pressed()), SLOT(add()));
	connect(removeButton, SIGNAL(pressed()), SLOT(remove()));

	connect(selector, SIGNAL(added(QListWidgetItem *)), SLOT(update()));
	connect(selector, SIGNAL(removed(QListWidgetItem *)), SLOT(update()));
	connect(selector, SIGNAL(movedUp(QListWidgetItem *)), SLOT(update()));
	connect(selector, SIGNAL(movedDown(QListWidgetItem *)), SLOT(update()));
}

void DictEditConf::update()
{
	groups->update(groupbox->currentText(), selected());
}

void DictEditConf::add()
{
	QString text = QInputDialog::getText(this, i18n("Add Group"), i18n("New Group:")).trimmed();

	if (!text.isEmpty()) {
		int index = groupbox->findText(text);
		if (index < 0) {
			groupbox->addItem(text);
			groups->add(text);
		}
		index = groupbox->findText(text);
		groupbox->setCurrentIndex(index);
		select(index);
	}
}

void DictEditConf::remove()
{
	QString text = groupbox->currentText();
	groupbox->removeItem(groupbox->currentIndex());
	select(groupbox->currentIndex());
	groups->remove(text);
}

void DictEditConf::select(int index)
{
	QListWidget *availableList = selector->availableListWidget();
	QListWidget *selectedList = selector->selectedListWidget();
	availableList->clear();
	selectedList->clear();

	foreach (QListWidgetItem *item, databaseList)
		availableList->addItem(new QListWidgetItem(*item));

	if (index >= 0) {
		QStringList database = groups->selected(groupbox->itemText(index));

		foreach (QString name, database)
			for (int i = 0; i < availableList->count(); ++i)
				if (name == availableList->item(i)->data(Qt::UserRole).toString())
					selectedList->addItem(availableList->takeItem(i));
	}
	selector->setEnabled(index >= 0);
	groupbox->setEnabled(index >= 0);
	removeButton->setEnabled(index >= 0);

	availableList->sortItems();
}

void DictEditConf::set(DictEdit *edit, const QList<QListWidgetItem *> &dblist)
{
	groups = edit;
	groupbox->clear();
	groupbox->addItems(edit->groups());

	databaseList.clear();
	databaseList.append(dblist);

	select(groupbox->currentIndex());
}

QStringList DictEditConf::selected() const
{
	QStringList list;
	QListWidget *selectedList = selector->selectedListWidget();
	for (int i = 0; i < selectedList->count(); ++i)
		list << selectedList->item(i)->data(Qt::UserRole).toString();
	return list;
}


#include <KConfig>
#include <KConfigGroup>
#include <KGlobal>


DictEdit::DictEdit(const QStringList &list)
{
	readConf(list);
}

void DictEdit::readConf(const QStringList &list)
{
	KConfigGroup groupConf(KGlobal::config(), "Groups");

	grouplist.clear();
	foreach (QString group, list) {
		QStringList database;
		database = groupConf.readEntry(group, database);
		grouplist << qMakePair(group, database);
	}
}

void DictEdit::writeConf()
{
	KConfigGroup groupConf(KGlobal::config(), "Groups");

	foreach (DictGroupPair group, grouplist)
		groupConf.writeEntry(group.first, group.second);
}

QStringList DictEdit::groups() const
{
	QStringList list;
	foreach (DictGroupPair pair, grouplist)
		list << pair.first;
	return list;
}

void DictEdit::add(const QString &text)
{
	grouplist.append(qMakePair(text, QStringList()));
}

void DictEdit::remove(const QString &text)
{
	int index = groups().indexOf(text);
	if (index >= 0)
		grouplist.removeAt(index);
}

void DictEdit::update(const QString &text, const QStringList &list)
{
	int index = groups().indexOf(text);
	if (index >= 0)
		grouplist[index].second = list;
}

QStringList DictEdit::selected(const QString &text) const
{
	int index = groups().indexOf(text);
	return (index >= 0) ? grouplist[index].second : QStringList();
}
