#ifndef DICTPAGE_H
#define DICTPAGE_H

#include "dict.h"
#include "dictformatter.h"

class DictPage : public QObject
{
	Q_OBJECT

public:
	enum Warning {
		LongSelection = 1, UrlSelection, UrlRequested
	};
	enum Error {
		UnknownDatabase = 1, MalformedURL, UnsupportedScheme,
		FileSystem
	};
	DictPage() { headings = true; correct = false; reformat = true; }
	DictPage(const DictResponse &response);
	void set(const DictResponse &response, bool append = false);
	void setTitle(const QString &title) { query = title; }
	QString title() const { return query; }
	QString htmltext() const { return html; }

	void error(const QString &text, int code);
	void warning(const QString &text, Warning type);
	void about(const QString &text, const QString &version);
	void help(const QString &text);
	void nomatches(const QString &text, bool define);
	void corrections(bool found);
	void correcting(bool on) { correct = on; }
	void status(const Dict *dict);

	int type() const { return typeCode; }
	void setHeadings(bool on) { headings = on; }
	void setReformat(bool on) { reformat = on; }
	DictFormatter *dictformatter() { return &formatter; }

Q_SIGNALS:
	void changed(bool append = false);

private:
	bool headings, correct, reformat;
	static int maxMatches, maxSuggestions;
	QString query, html;
	int typeCode;
	DictFormatter formatter;

	void heading(const QString &text);
	void matches(const QStringList &list);
	void server(const QString &text);
	void databases(const DictList &list);
	void strategies(const DictList &list);
	void suggestions(const QString &text, const QStringList &list);
	void status(const QString &message);
	void status(const QString &title, const QString &desc);
};

#endif
