#include "dictsettings.h"
#include "dictselection.h"
#include "dictwindow.h"
#include "dict.h"

#include <KConfig>


DictConf::DictConf()
{
	config = KGlobal::config();
}

DictConf::~DictConf()
{
	config->sync();
}

void DictConf::read()
{
	KConfigGroup mainConf(config, Dikt::AppName);

	corrections = mainConf.readEntry("Corrections", true);
	headings = mainConf.readEntry("Headings", true);
	matchPage = mainConf.readEntry("MatchPage", true);
	autoMatch = mainConf.readEntry("AutoMatch", false);
	autoStrategy = mainConf.readEntry("AutoStrategy", 1);
	defaultSearch = mainConf.readEntry("DefaultSearch", 0);
	reformat = mainConf.readEntry("Reformat", true);
}

void DictConf::write()
{
	KConfigGroup mainConf(config, Dikt::AppName);

	mainConf.writeEntry("Corrections", corrections);
	mainConf.writeEntry("Headings", headings);
	mainConf.writeEntry("MatchPage", matchPage);
	mainConf.writeEntry("AutoMatch", autoMatch);
	mainConf.writeEntry("AutoStrategy", autoStrategy);
	mainConf.writeEntry("DefaultSearch", defaultSearch);
	mainConf.writeEntry("Reformat", reformat);
}

DictSelectionConf DictConf::selection(void)
{
	DictSelectionConf conf;

	KConfigGroup yankConf(config, "Selections");

	conf.yank = yankConf.readEntry("Yank", false);
	conf.local = yankConf.readEntry("Local", true);
	conf.remote = yankConf.readEntry("Remote", true);

	conf.minLen = yankConf.readEntry("MinLen", 2);
	conf.maxLen = yankConf.readEntry("MaxLen", 120);
	conf.warnLen = yankConf.readEntry("WarnLen", 40);
	conf.modifier = yankConf.readEntry("ModifierKey", 0);

	return conf;
}

void DictConf::writeSelection(const DictSelectionConf &conf)
{
	KConfigGroup yankConf(config, "Selections");

	yankConf.writeEntry("Yank" , conf.yank);
	yankConf.writeEntry("Local" , conf.local);
	yankConf.writeEntry("Remote" , conf.remote);

	yankConf.writeEntry("MinLen", conf.minLen);
	yankConf.writeEntry("MaxLen", conf.maxLen);
	yankConf.writeEntry("WarnLen", conf.warnLen);
	yankConf.writeEntry("ModifierKey", conf.modifier);
}

void DictConf::writeServer(const QStringList &hosts)
{
	KConfigGroup serverConf(config, "Server");
	serverConf.writeEntry("Hosts", hosts);
	serverConf.writeEntry("Selected", hosts.indexOf(dicthost));
}

void DictConf::writeHost(const QStringList &database, const QString &strategy)
{
	KConfigGroup hostConf(config, dicthost);
	hostConf.writeEntry("Database", database);
	hostConf.writeEntry("Strategy", strategy);
}

QStringList DictConf::server()
{
	KConfigGroup serverConf(config, "Server");
	return serverConf.readEntry("Hosts", QStringList());
}

QString DictConf::host()
{
	KConfigGroup serverConf(config, "Server");
	int selected = serverConf.readEntry("Selected", 0);

	QStringList hosts = server();
	if (selected < 0 || selected >= hosts.size())
		return Dict::DefaultHost;

	return hosts[selected];
}

int DictConf::port()
{
	KConfigGroup hostConf(config, dicthost);
	return hostConf.readEntry("Port", Dict::DefaultPort);
}

QStringList DictConf::database()
{
	KConfigGroup hostConf(config, dicthost);
	return hostConf.readEntry("Database", QStringList());
}

QString DictConf::strategy()
{
	KConfigGroup hostConf(config, dicthost);
	return hostConf.readEntry("Strategy", QString());
}

int DictConf::selected()
{
	KConfigGroup hostConf(config, dicthost);
	return hostConf.readEntry("Selected", 0);
}

void DictConf::writeSelected(int selected)
{
	KConfigGroup hostConf(config, dicthost);
	hostConf.writeEntry("Selected", selected);
}

QStringList DictConf::groups()
{
	KConfigGroup hostConf(config, dicthost);
	return hostConf.readEntry("Groups", QStringList());
}

void DictConf::writeGroups(const QStringList &groups)
{
	KConfigGroup hostConf(config, dicthost);
	hostConf.writeEntry("Groups", groups);
}

QString DictConf::username()
{
	KConfigGroup hostConf(config, dicthost);
	return hostConf.readEntry("Username", "");
}

QString DictConf::password()
{
	KConfigGroup hostConf(config, dicthost);
	return hostConf.readEntry("Password", "");
}

void DictConf::writeUser(const QString &username, const QString &password)
{
	KConfigGroup hostConf(config, dicthost);
	hostConf.writeEntry("Username", username);
	hostConf.writeEntry("Password", password);
}

void DictConf::deleteUser()
{
	KConfigGroup hostConf(config, dicthost);
	hostConf.deleteEntry("Username");
	hostConf.deleteEntry("Password");
}

int DictConf::sidebar()
{
	KConfigGroup mainConf(config, Dikt::AppName);
	sidebarSide = mainConf.readEntry("Sidebar", 1);
	if (sidebarSide) sidebarSide = 1;
	return sidebarSide;
}

QList<int> DictConf::widths()
{
	KConfigGroup mainConf(config, Dikt::AppName);
	QList<int> widths;
	widths << 100 << 200;
	return mainConf.readEntry("Widths", widths);
}

bool DictConf::sidebarVisible()
{
	KConfigGroup mainConf(config, Dikt::AppName);
	return mainConf.readEntry("Splitter", false);
}

int DictConf::stack()
{
	KConfigGroup mainConf(config, Dikt::AppName);
	return mainConf.readEntry("Stack", 0);
}

void DictConf::writeSidebar(int index)
{
	KConfigGroup mainConf(config, Dikt::AppName);
	mainConf.writeEntry("Sidebar", sidebarSide);
	mainConf.writeEntry("Stack", index);
}

void DictConf::writeWidths(QList<int> sizes)
{
	KConfigGroup mainConf(config, Dikt::AppName);
	bool visible = sizes[0] && sizes[1];
	if (visible)
		mainConf.writeEntry("Widths", sizes);
	mainConf.writeEntry("Splitter", visible);
}

QFont DictConf::font()
{
	KConfigGroup mainConf(config, Dikt::AppName);
	QFont font;
	font.fromString(mainConf.readEntry("Font", "Sans Serif"));
	return font;
}

void DictConf::writeFont(const QFont &font)
{
	KConfigGroup mainConf(config, Dikt::AppName);
	mainConf.writeEntry("Font", font.toString());
}


DictSettings::DictSettings(QWidget *parent)
	: KDialog(parent)
{
	setupUi(this);
	setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Apply);
	setMainWidget(tab);
}

QStringList DictSettings::hosts()
{
	return listbox->items();
}

void DictSettings::setHosts(const QStringList &hosts)
{
	listbox->setItems(hosts);
}

QFont DictSettings::font()
{
	return fontrequester->font();
}

void DictSettings::setFont(const QFont &font)
{
	fontrequester->setFont(font);
}

void DictSettings::setStyle(DictStyle *style)
{
	styleconf->setStyle(style);
}

void DictSettings::setSelection(const DictSelectionConf &conf)
{
	yank->setChecked(conf.yank);
	localYank->setChecked(conf.local);
	remoteYank->setChecked(conf.remote);

	modifierKey->setCurrentIndex(conf.modifier);

	yankMin->setValue(conf.minLen);
	yankMax->setValue(conf.maxLen);
	yankWarn->setValue(conf.warnLen);
}

DictSelectionConf DictSettings::selection(void)
{
	DictSelectionConf conf;

	conf.yank = yank->isChecked();
	conf.local = localYank->isChecked();
	conf.remote = remoteYank->isChecked();

	conf.modifier = modifierKey->currentIndex();

	conf.minLen = yankMin->value();
	conf.maxLen = yankMax->value();
	conf.warnLen = yankWarn->value();

	return conf;
}

void DictSettings::readConf(const DictConf &conf)
{
	corrections->setChecked(conf.corrections);
	headings->setChecked(conf.headings);
	matchPage->setChecked(conf.matchPage);
	autoMatch->setChecked(conf.autoMatch);
	autoStrategy->setCurrentIndex(conf.autoStrategy);
	sidebar->setCurrentIndex(conf.sidebarSide);

	reformat->setChecked(conf.reformat);
}

void DictSettings::writeConf(DictConf &conf)
{
	conf.corrections = corrections->isChecked();
	conf.headings = headings->isChecked();
	conf.matchPage = matchPage->isChecked();
	conf.autoMatch = autoMatch->isChecked();
	conf.autoStrategy = autoStrategy->currentIndex();
	conf.sidebarSide = sidebar->currentIndex();

	conf.reformat = reformat->isChecked();
}
