#ifndef DICTSTYLE_H
#define DICTSTYLE_H

#include <QTreeWidget>


class DictStyleItem : public QObject, public QTreeWidgetItem
{
	Q_OBJECT

public:
	enum Column {
		Context,
		Bold, Italic, Underline,
		Text, Back
	};
	enum FontStyle {
		NormalFont, BoldFont, ItalicFont, UnderlineFont = 4
	};
	DictStyleItem(const QString &context);
	QString context() const { return type; }

	int style() const;
	bool bold() const;
	bool italic() const;
	bool underline() const;
	QString text() const;
	QString back() const;

	void set(int style, const QString &text, const QString &back);
	void setFonts(int column);
	void setCheckBoxes();
	void setColorWidgets();

private Q_SLOTS:
	void setTextColor(const QColor &);
	void setBackColor(const QColor &);

private:
	QString type;
};

typedef QList<DictStyleItem *> DictStyleList;


class DictStyle
{
public:
	DictStyle();
	~DictStyle();

	const DictStyleList &itemList() const { return stylelist; }
	QString stylesheet() const;

	void setDefaults();
	void readConf();
	void writeConf();

private:
	enum Context {
		Title, Headword, Abbreviation, Pronunciation, Description, Link
	};
	DictStyleList stylelist;
};


class DictStyleConf : public QTreeWidget
{
	Q_OBJECT

public:
	DictStyleConf(QWidget *parent);
	void setStyle(DictStyle *style);

private Q_SLOTS:
	void setFonts(QTreeWidgetItem *, int);
};

#endif
