#ifndef DICTTRACKER_H
#define DICTTRACKER_H

#include "dict.h"

class DictPage;

class DictTracker : public QObject
{
	Q_OBJECT

public:
	DictTracker(Dict *dict, DictPage *word, DictPage *match = 0);

	void define(const QString &query);
	void match(const QString &query, const QString &strategy);
	void info(const QString &query, const QString &text);
	void init();
	void cancel();

	void setCorrect(bool on) { correct = on; }
	void setMatchPage(DictPage *match) { matchPage = match; }
	void setAutoMatch(bool on) { automatch = on; }
	void setAutoStrategy(int strategy);
	void setDefaultDatabase(int database);

	QStringList databases() const { return database; }

private:
	enum DictInit { Stopped, Started, Databases, Strategies = 4 };
	int dictinit;
	bool defining, matching, correcting, appending, automatching;
	int hits, misses, dbcount;
	void reset() { hits = misses = 0; }
	int count() { return hits + misses; }
	void clear();
	void done();
	void suggestions();
	void automatches();

	Dict *dict;
	DictPage *wordPage, *matchPage;
	bool correct, automatch;
	QString query, strategy;
	QStringList database;
	QString defaultDatabase, defaultStrategy, autoStrategy;

public Q_SLOTS:
	void response(const DictResponse &response);
	void setDatabase(const QStringList &database);
	void setStrategy(const QString &strategy);

Q_SIGNALS:
	void words();
	void matches(bool);
	void corrections();
	void loading(bool);
	void databases(const DictList &list);
	void strategies(const DictList &list);
	void progress(int current, int total);
};

#endif
