#ifndef DICTWIDGETS_H
#define DICTWIDGETS_H

#include "dict.h"

#include <KActionMenu>

class DictInfo : public KActionMenu
{
	Q_OBJECT

public:
	DictInfo(QObject *parent = 0);
	void addAction(const QString &text, const QString &data);
	QStringList list() const;

Q_SIGNALS:
	void selected(const QString &);

protected Q_SLOTS:
	virtual void actionTriggered(QAction *action);
};


#include <KSelectAction>

class QComboBox;

class DictSelect : public KSelectAction
{
	Q_OBJECT

public:
	DictSelect(QObject *parent = 0);
	QString current() const;
	void setList(const DictList &list, const QString &selected);
	void setEnabled(bool);
	void clear();

public Q_SLOTS:
	void setCurrent(const QString &data);
	void setFocus();

private Q_SLOTS:
	void actionTriggered(QAction *action);

private:
	QWidget *createWidget(QWidget *parent);
	void deleteWidget(QWidget *parent);

	QComboBox *combobox;
};


#include <KMenu>

class DictMenu : public DictInfo
{
	Q_OBJECT

public:
	DictMenu(QObject *parent = 0);
	QStringList current() const { return currentData(QAction::menu()); }
	void setList(const DictList &list, const QStringList &selected);
	QStringList list() const { return listData(QAction::menu()); }
	void clear() { menu()->clear(); }
	void setMenuLength(int length) { menuLen = length; }

public Q_SLOTS:
	void setCurrent(const QStringList &data) { setCurrentData(data, menu()); }

Q_SIGNALS:
	void selected(const QStringList &);

private Q_SLOTS:
	void actionTriggered(QAction *action);

private:
	QStringList listData(const QMenu *submenu) const;
	QStringList currentData(const QMenu *submenu) const;
	void setCurrentData(const QStringList &data, const QMenu *submenu);

	int menuLen;
};


#include <QListWidget>

class DictView : public QListWidget
{
	Q_OBJECT

public:
	DictView(QWidget *parent = 0);
	void setList(const DictList &list, const QStringList &selected);
	const QList<QListWidgetItem *> list() const;

Q_SIGNALS:
	void selected(const QStringList&);

public Q_SLOTS:
	void setCurrent(const QStringList &list);

private Q_SLOTS:
	void selection();

private:
	QString data(int index) const;
};


#include "dictgroup.h"

class DictDatabase : public KActionMenu
{
	Q_OBJECT

public:
	DictDatabase(QObject *parent = 0);
	void setMenu(DictMenu *menu, QAction *edit);
	void setGroups(const DictGroupList &list);
	void checkList(void);
	void setChecked(int);
	int checked() const;
	QStringList current() const;

Q_SIGNALS:
	void selected(const QStringList &);

public Q_SLOTS:
	void setList();

private Q_SLOTS:
	void update();
	void actionTriggered(QAction *action);

private:
	void addAction(const QString &text, const QStringList &data);
	QActionGroup *group;
	DictMenu *dbmenu;
	QAction *dbedit;
};


#include "dictbrowser.h"

class DictHistory : public QMenu
{
	Q_OBJECT

public:
	enum Direction { Backward, Forward };
	DictHistory(DictBrowser *parent, Direction direction);

Q_SIGNALS:
	void selected(int);

private Q_SLOTS:
	void setList(const QStringList &list);
	void steps(QAction *action);
	void setMenu();

private:
	Direction direction;
	DictBrowser *browser;
};


#include "ui_searchbar.h"
#include <QWidget>

class DictSearch : public QWidget, public Ui::Searchbar
{
	Q_OBJECT

public:
	DictSearch(DictBrowser *parent);

public Q_SLOTS:
	void next() { find(); }
	void prev() { find(QTextDocument::FindBackward); }

	void show();
	void hide();
	void clear();

private Q_SLOTS:
	void find(QTextDocument::FindFlags direction = 0);
	void search(const QString &text);

private:
	DictBrowser *browser;
	bool found;

	void keyPressEvent(QKeyEvent *event);
};


class DictStatus : public QWidget
{
	Q_OBJECT

public:
	DictStatus(QWidget *parent);

public Q_SLOTS:
	void setStatus(const char *icon, const QString &text, bool enabled);
	void setTip(const QString &text);

private:
	QLabel *picture, *label;
};


#include <QProgressBar>
#include <QTimer>

class DictProgress : public QProgressBar
{
	Q_OBJECT

public:
	DictProgress(QWidget *parent);

public Q_SLOTS:
	void set(int current, int total);

private:
	QTimer timer;
};


#include <QComboBox>

class DictEntry : public QComboBox
{
public:
	DictEntry(QWidget *parent);
};

#endif
